# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/datasource/v1/logsource.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/datasource/v1/logsource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0insightproto/proto/datasource/v1/logsource.proto\x12 insightproto.proto.datasource.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\"\xd0\x01\n\x08LogEntry\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05level\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x46\n\x06labels\x18\x04 \x03(\x0b\x32\x36.insightproto.proto.datasource.v1.LogEntry.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x01\n\x08Metadata\x12\x11\n\tlog_count\x18\x01 \x01(\x05\x12\x34\n\x06source\x18\x02 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x88\x01\n\x0bLogResponse\x12;\n\x07\x65ntries\x18\x01 \x03(\x0b\x32*.insightproto.proto.datasource.v1.LogEntry\x12<\n\x08metadata\x18\x02 \x01(\x0b\x32*.insightproto.proto.datasource.v1.Metadata\"\xab\x02\n\nLogRequest\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05query\x18\x03 \x01(\t\x12H\n\x06labels\x18\x04 \x03(\x0b\x32\x38.insightproto.proto.datasource.v1.LogRequest.LabelsEntry\x12\x37\n\x03org\x18\x05 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x10MultipleResponse\x12\x37\n\x03org\x18\x01 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12@\n\tresponses\x18\x02 \x03(\x0b\x32-.insightproto.proto.datasource.v1.LogResponse2\xec\x01\n\x0eLoggingService\x12m\n\tQueryLogs\x12,.insightproto.proto.datasource.v1.LogRequest\x1a\x32.insightproto.proto.datasource.v1.MultipleResponse\x12k\n\nStreamLogs\x12,.insightproto.proto.datasource.v1.LogRequest\x1a-.insightproto.proto.datasource.v1.LogResponse0\x01\x42\x35Z3github.com/opentrace/insight-proto-go/datasource/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.datasource.v1.logsource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/opentrace/insight-proto-go/datasource/v1'
  _globals['_LOGENTRY_LABELSENTRY']._loaded_options = None
  _globals['_LOGENTRY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LOGREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_LOGREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LOGENTRY']._serialized_start=163
  _globals['_LOGENTRY']._serialized_end=371
  _globals['_LOGENTRY_LABELSENTRY']._serialized_start=326
  _globals['_LOGENTRY_LABELSENTRY']._serialized_end=371
  _globals['_METADATA']._serialized_start=374
  _globals['_METADATA']._serialized_end=551
  _globals['_LOGRESPONSE']._serialized_start=554
  _globals['_LOGRESPONSE']._serialized_end=690
  _globals['_LOGREQUEST']._serialized_start=693
  _globals['_LOGREQUEST']._serialized_end=992
  _globals['_LOGREQUEST_LABELSENTRY']._serialized_start=326
  _globals['_LOGREQUEST_LABELSENTRY']._serialized_end=371
  _globals['_MULTIPLERESPONSE']._serialized_start=995
  _globals['_MULTIPLERESPONSE']._serialized_end=1136
  _globals['_LOGGINGSERVICE']._serialized_start=1139
  _globals['_LOGGINGSERVICE']._serialized_end=1375
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/jobs/v1/jobs.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/jobs/v1/jobs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.jobs.v1 import job_service_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_job__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%insightproto/proto/jobs/v1/jobs.proto\x12\x1ainsightproto.proto.jobs.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a,insightproto/proto/jobs/v1/job_service.proto\"\xd8\x03\n\nJobMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x43\n\x0fidempotency_key\x18\x07 \x01(\tB*\x9a\x84\x9e\x03%firestore:\"idempotency_key,omitempty\"\x12;\n\naether_job\x18\x03 \x01(\x0b\x32%.insightproto.proto.jobs.v1.AetherJobH\x00\x12=\n\x0binsight_job\x18\x04 \x01(\x0b\x32&.insightproto.proto.jobs.v1.InsightJobH\x00\x12\x41\n\rsimulator_job\x18\x05 \x01(\x0b\x32(.insightproto.proto.jobs.v1.SimulatorJobH\x00\x12\x41\n\rknowledge_job\x18\x06 \x01(\x0b\x32(.insightproto.proto.jobs.v1.KnowledgeJobH\x00\x12\x37\n\x08\x63hat_job\x18\x08 \x01(\x0b\x32#.insightproto.proto.jobs.v1.ChatJobH\x00\x42\x05\n\x03job\"\xd0\x02\n\x0cSimulatorJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x61gent\x18\x02 \x01(\t\x12\x12\n\x06inputs\x18\x03 \x03(\tB\x02\x18\x01\x12t\n\rinsight_agent\x18\x04 \x01(\x0b\x32..insightproto.proto.jobs.v1.InsightAgentConfigB(\x9a\x84\x9e\x03#firestore:\"insight_agent,omitempty\"H\x00\x88\x01\x01\x12\x17\n\ntest_suite\x18\x05 \x01(\tH\x01\x88\x01\x01\x12W\n\x05\x65rror\x18\x06 \x01(\x0b\x32!.insightproto.proto.jobs.v1.ErrorB \x9a\x84\x9e\x03\x1b\x66irestore:\"error,omitempty\"H\x02\x88\x01\x01\x42\x10\n\x0e_insight_agentB\r\n\x0b_test_suiteB\x08\n\x06_error\"\x8f\x02\n\x12InsightAgentConfig\x12p\n\x0binvestigate\x18\x01 \x01(\x0b\x32..insightproto.proto.jobs.v1.InvestigateCommandB&\x9a\x84\x9e\x03!firestore:\"investigate,omitempty\"H\x00\x88\x01\x01\x12i\n\trun_agent\x18\x02 \x01(\x0b\x32+.insightproto.proto.jobs.v1.RunAgentCommandB$\x9a\x84\x9e\x03\x1f\x66irestore:\"run_agent,omitempty\"H\x01\x88\x01\x01\x42\x0e\n\x0c_investigateB\x0c\n\n_run_agent\"#\n\x12InvestigateCommand\x12\r\n\x05query\x18\x01 \x01(\t\"\\\n\x0fRunAgentCommand\x12\x13\n\x0b\x61gent_class\x18\x01 \x01(\t\x12\x13\n\x0bserver_name\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\"\xc6\x02\n\x07\x43hatJob\x12\x17\n\x0f\x63onversation_id\x18\x01 \x01(\t\x12\x13\n\x0bresponse_id\x18\x02 \x01(\t\x12\\\n\x07history\x18\x03 \x03(\x0b\x32\'.insightproto.proto.jobs.v1.ChatMessageB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"history,omitempty\"\x12@\n\x0f\x63urrent_message\x18\x04 \x01(\x0b\x32\'.insightproto.proto.jobs.v1.ChatMessage\x12\x61\n\x07\x63ontext\x18\x05 \x01(\x0b\x32\'.insightproto.proto.jobs.v1.ChatContextB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"context,omitempty\"H\x00\x88\x01\x01\x42\n\n\x08_context\"[\n\x0b\x43hatMessage\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa5\x01\n\x0b\x43hatContext\x12J\n\x10investigation_id\x18\x01 \x01(\tB+\x9a\x84\x9e\x03&firestore:\"investigation_id,omitempty\"H\x00\x88\x01\x01\x12\x35\n\x08node_ids\x18\x02 \x03(\tB#\x9a\x84\x9e\x03\x1e\x66irestore:\"node_ids,omitempty\"B\x13\n\x11_investigation_id\"\xf9\x04\n\x0cKnowledgeJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x06source\x18\x02 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12\x65\n\x07project\x18\x03 \x01(\x0b\x32+.insightproto.proto.jobs.v1.ProviderProjectB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"project,omitempty\"H\x00\x88\x01\x01\x12Z\n\x06\x61uthor\x18\x04 \x01(\x0b\x32\".insightproto.proto.jobs.v1.AuthorB!\x9a\x84\x9e\x03\x1c\x66irestore:\"author,omitempty\"H\x01\x88\x01\x01\x12l\n\nkubernetes\x18\x05 \x01(\x0b\x32,.insightproto.proto.jobs.v1.KubernetesConfigB%\x9a\x84\x9e\x03 firestore:\"kubernetes,omitempty\"H\x02\x88\x01\x01\x12]\n\x05issue\x18\x06 \x01(\x0b\x32\'.insightproto.proto.jobs.v1.IssueConfigB \x9a\x84\x9e\x03\x1b\x66irestore:\"issue,omitempty\"H\x03\x88\x01\x01\x12]\n\x05trace\x18\x07 \x01(\x0b\x32\'.insightproto.proto.jobs.v1.TraceConfigB \x9a\x84\x9e\x03\x1b\x66irestore:\"trace,omitempty\"H\x04\x88\x01\x01\x42\n\n\x08_projectB\t\n\x07_authorB\r\n\x0b_kubernetesB\x08\n\x06_issueB\x08\n\x06_trace\"P\n\x0bTraceConfig\x12\x41\n\x0eservice_filter\x18\x01 \x03(\tB)\x9a\x84\x9e\x03$firestore:\"service_filter,omitempty\"\"\xb6\x02\n\x10KubernetesConfig\x12\x45\n\x10namespace_filter\x18\x01 \x03(\tB+\x9a\x84\x9e\x03&firestore:\"namespace_filter,omitempty\"\x12W\n\x19include_system_namespaces\x18\x02 \x01(\x08\x42\x34\x9a\x84\x9e\x03/firestore:\"include_system_namespaces,omitempty\"\x12=\n\x0c\x63luster_name\x18\x03 \x01(\tB\'\x9a\x84\x9e\x03\"firestore:\"cluster_name,omitempty\"\x12\x43\n\x0f\x63luster_context\x18\x04 \x01(\tB*\x9a\x84\x9e\x03%firestore:\"cluster_context,omitempty\"\"%\n\x0bIssueConfig\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x05\n\x03_id\"\xde\x02\n\tAetherJob\x12\n\n\x02id\x18\x01 \x01(\t\x12<\n\x07project\x18\x02 \x01(\x0b\x32+.insightproto.proto.jobs.v1.ProviderProject\x12\x15\n\rOperationType\x18\x03 \x01(\t\x12\x14\n\x07IssueId\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0c\x44iscussionId\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0eMergeRequestId\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05JobId\x18\x07 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06NoteId\x18\x08 \x01(\tH\x04\x88\x01\x01\x12\x34\n\x06source\x18\t \x01(\x0b\x32$.insightproto.proto.common.v1.SourceB\n\n\x08_IssueIdB\x0f\n\r_DiscussionIdB\x11\n\x0f_MergeRequestIdB\x08\n\x06_JobIdB\t\n\x07_NoteId\"\x95\x01\n\x0fProviderProject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12:\n\x08provider\x18\x03 \x01(\x0b\x32$.insightproto.proto.jobs.v1.ProviderB\x02\x18\x01\x12\x1b\n\x13\x64\x65\x66\x61ult_branch_name\x18\x04 \x01(\t\x12\x0f\n\x07git_url\x18\x05 \x01(\t\"B\n\x08Provider\x12\x0e\n\x02id\x18\x01 \x01(\tB\x02\x18\x01\x12\x12\n\x06source\x18\x02 \x01(\tB\x02\x18\x01\x12\x12\n\x06gitUrl\x18\x03 \x01(\tB\x02\x18\x01\"N\n\nInsightJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x07trigger\x18\x02 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\"\xd4\x02\n\x07Trigger\x12\x34\n\x06source\x18\x01 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x42\n\x0creference_id\x18\x03 \x01(\tB\'\x9a\x84\x9e\x03\"firestore:\"reference_id,omitempty\"H\x00\x88\x01\x01\x12\x32\n\x06\x61uthor\x18\x04 \x01(\x0b\x32\".insightproto.proto.jobs.v1.Author\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\nchannel_id\x18\x06 \x01(\tB%\x9a\x84\x9e\x03 firestore:\"channel_id,omitempty\"H\x01\x88\x01\x01\x42\x0f\n\r_reference_idB\r\n\x0b_channel_id\"2\n\x06\x41uthor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\tB/Z-github.com/opentrace/insight-proto-go/jobs/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.jobs.v1.jobs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/opentrace/insight-proto-go/jobs/v1'
  _globals['_JOBMESSAGE'].fields_by_name['idempotency_key']._loaded_options = None
  _globals['_JOBMESSAGE'].fields_by_name['idempotency_key']._serialized_options = b'\232\204\236\003%firestore:\"idempotency_key,omitempty\"'
  _globals['_SIMULATORJOB'].fields_by_name['inputs']._loaded_options = None
  _globals['_SIMULATORJOB'].fields_by_name['inputs']._serialized_options = b'\030\001'
  _globals['_SIMULATORJOB'].fields_by_name['insight_agent']._loaded_options = None
  _globals['_SIMULATORJOB'].fields_by_name['insight_agent']._serialized_options = b'\232\204\236\003#firestore:\"insight_agent,omitempty\"'
  _globals['_SIMULATORJOB'].fields_by_name['error']._loaded_options = None
  _globals['_SIMULATORJOB'].fields_by_name['error']._serialized_options = b'\232\204\236\003\033firestore:\"error,omitempty\"'
  _globals['_INSIGHTAGENTCONFIG'].fields_by_name['investigate']._loaded_options = None
  _globals['_INSIGHTAGENTCONFIG'].fields_by_name['investigate']._serialized_options = b'\232\204\236\003!firestore:\"investigate,omitempty\"'
  _globals['_INSIGHTAGENTCONFIG'].fields_by_name['run_agent']._loaded_options = None
  _globals['_INSIGHTAGENTCONFIG'].fields_by_name['run_agent']._serialized_options = b'\232\204\236\003\037firestore:\"run_agent,omitempty\"'
  _globals['_CHATJOB'].fields_by_name['history']._loaded_options = None
  _globals['_CHATJOB'].fields_by_name['history']._serialized_options = b'\232\204\236\003\035firestore:\"history,omitempty\"'
  _globals['_CHATJOB'].fields_by_name['context']._loaded_options = None
  _globals['_CHATJOB'].fields_by_name['context']._serialized_options = b'\232\204\236\003\035firestore:\"context,omitempty\"'
  _globals['_CHATCONTEXT'].fields_by_name['investigation_id']._loaded_options = None
  _globals['_CHATCONTEXT'].fields_by_name['investigation_id']._serialized_options = b'\232\204\236\003&firestore:\"investigation_id,omitempty\"'
  _globals['_CHATCONTEXT'].fields_by_name['node_ids']._loaded_options = None
  _globals['_CHATCONTEXT'].fields_by_name['node_ids']._serialized_options = b'\232\204\236\003\036firestore:\"node_ids,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['project']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['project']._serialized_options = b'\232\204\236\003\035firestore:\"project,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['author']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['author']._serialized_options = b'\232\204\236\003\034firestore:\"author,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['kubernetes']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['kubernetes']._serialized_options = b'\232\204\236\003 firestore:\"kubernetes,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['issue']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['issue']._serialized_options = b'\232\204\236\003\033firestore:\"issue,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['trace']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['trace']._serialized_options = b'\232\204\236\003\033firestore:\"trace,omitempty\"'
  _globals['_TRACECONFIG'].fields_by_name['service_filter']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['service_filter']._serialized_options = b'\232\204\236\003$firestore:\"service_filter,omitempty\"'
  _globals['_KUBERNETESCONFIG'].fields_by_name['namespace_filter']._loaded_options = None
  _globals['_KUBERNETESCONFIG'].fields_by_name['namespace_filter']._serialized_options = b'\232\204\236\003&firestore:\"namespace_filter,omitempty\"'
  _globals['_KUBERNETESCONFIG'].fields_by_name['include_system_namespaces']._loaded_options = None
  _globals['_KUBERNETESCONFIG'].fields_by_name['include_system_namespaces']._serialized_options = b'\232\204\236\003/firestore:\"include_system_namespaces,omitempty\"'
  _globals['_KUBERNETESCONFIG'].fields_by_name['cluster_name']._loaded_options = None
  _globals['_KUBERNETESCONFIG'].fields_by_name['cluster_name']._serialized_options = b'\232\204\236\003\"firestore:\"cluster_name,omitempty\"'
  _globals['_KUBERNETESCONFIG'].fields_by_name['cluster_context']._loaded_options = None
  _globals['_KUBERNETESCONFIG'].fields_by_name['cluster_context']._serialized_options = b'\232\204\236\003%firestore:\"cluster_context,omitempty\"'
  _globals['_PROVIDERPROJECT'].fields_by_name['provider']._loaded_options = None
  _globals['_PROVIDERPROJECT'].fields_by_name['provider']._serialized_options = b'\030\001'
  _globals['_PROVIDER'].fields_by_name['id']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['id']._serialized_options = b'\030\001'
  _globals['_PROVIDER'].fields_by_name['source']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['source']._serialized_options = b'\030\001'
  _globals['_PROVIDER'].fields_by_name['gitUrl']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['gitUrl']._serialized_options = b'\030\001'
  _globals['_TRIGGER'].fields_by_name['reference_id']._loaded_options = None
  _globals['_TRIGGER'].fields_by_name['reference_id']._serialized_options = b'\232\204\236\003\"firestore:\"reference_id,omitempty\"'
  _globals['_TRIGGER'].fields_by_name['channel_id']._loaded_options = None
  _globals['_TRIGGER'].fields_by_name['channel_id']._serialized_options = b'\232\204\236\003 firestore:\"channel_id,omitempty\"'
  _globals['_JOBMESSAGE']._serialized_start=192
  _globals['_JOBMESSAGE']._serialized_end=664
  _globals['_SIMULATORJOB']._serialized_start=667
  _globals['_SIMULATORJOB']._serialized_end=1003
  _globals['_INSIGHTAGENTCONFIG']._serialized_start=1006
  _globals['_INSIGHTAGENTCONFIG']._serialized_end=1277
  _globals['_INVESTIGATECOMMAND']._serialized_start=1279
  _globals['_INVESTIGATECOMMAND']._serialized_end=1314
  _globals['_RUNAGENTCOMMAND']._serialized_start=1316
  _globals['_RUNAGENTCOMMAND']._serialized_end=1408
  _globals['_CHATJOB']._serialized_start=1411
  _globals['_CHATJOB']._serialized_end=1737
  _globals['_CHATMESSAGE']._serialized_start=1739
  _globals['_CHATMESSAGE']._serialized_end=1830
  _globals['_CHATCONTEXT']._serialized_start=1833
  _globals['_CHATCONTEXT']._serialized_end=1998
  _globals['_KNOWLEDGEJOB']._serialized_start=2001
  _globals['_KNOWLEDGEJOB']._serialized_end=2634
  _globals['_TRACECONFIG']._serialized_start=2636
  _globals['_TRACECONFIG']._serialized_end=2716
  _globals['_KUBERNETESCONFIG']._serialized_start=2719
  _globals['_KUBERNETESCONFIG']._serialized_end=3029
  _globals['_ISSUECONFIG']._serialized_start=3031
  _globals['_ISSUECONFIG']._serialized_end=3068
  _globals['_AETHERJOB']._serialized_start=3071
  _globals['_AETHERJOB']._serialized_end=3421
  _globals['_PROVIDERPROJECT']._serialized_start=3424
  _globals['_PROVIDERPROJECT']._serialized_end=3573
  _globals['_PROVIDER']._serialized_start=3575
  _globals['_PROVIDER']._serialized_end=3641
  _globals['_INSIGHTJOB']._serialized_start=3643
  _globals['_INSIGHTJOB']._serialized_end=3721
  _globals['_TRIGGER']._serialized_start=3724
  _globals['_TRIGGER']._serialized_end=4064
  _globals['_AUTHOR']._serialized_start=4066
  _globals['_AUTHOR']._serialized_end=4116
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import insightproto.proto.common.v1.common_pb2
import insightproto.proto.results.v1.timeline_details_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Acquisition(google.protobuf.message.Message):
    """message wrapper for sending updates"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    KNOWLEDGE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the job"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    @property
    def knowledge(self) -> Global___KnowledgeActivity:
        """The completed knowledge acquisition"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        knowledge: Global___KnowledgeActivity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["knowledge", b"knowledge", "org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "knowledge", b"knowledge", "org", b"org"]) -> None: ...

Global___Acquisition: typing_extensions.TypeAlias = Acquisition

@typing.final
class KnowledgeActivity(google.protobuf.message.Message):
    """Knowledge graph activity event"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    CREATEDAT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    EXPIRESAT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """unique identifier for the activity"""
    title: builtins.str
    """title of the activity"""
    description: builtins.str
    """detailed description of the activity"""
    link: builtins.str
    """the link to the scanned data (e.g. the github repo that was scanned)"""
    @property
    def source(self) -> insightproto.proto.common.v1.common_pb2.Source:
        """source of activity performed - e.g. gitlab/grafana"""

    @property
    def author(self) -> insightproto.proto.results.v1.timeline_details_pb2.User:
        """user who performed the activity - a null or missing user indicates 'system'"""

    @property
    def createdAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timestamp when the activity occurred"""

    @property
    def metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___KnowledgeMetadata]:
        """the metadata of the nodes/relationships created"""

    @property
    def expiresAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timestamp when the activity expires"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        source: insightproto.proto.common.v1.common_pb2.Source | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        author: insightproto.proto.results.v1.timeline_details_pb2.User | None = ...,
        createdAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        link: builtins.str | None = ...,
        metadata: collections.abc.Iterable[Global___KnowledgeMetadata] | None = ...,
        expiresAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_author", b"_author", "_link", b"_link", "author", b"author", "createdAt", b"createdAt", "expiresAt", b"expiresAt", "link", b"link", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_author", b"_author", "_link", b"_link", "author", b"author", "createdAt", b"createdAt", "description", b"description", "expiresAt", b"expiresAt", "id", b"id", "link", b"link", "metadata", b"metadata", "source", b"source", "title", b"title"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_author", b"_author"]) -> typing.Literal["author"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_link", b"_link"]) -> typing.Literal["link"] | None: ...

Global___KnowledgeActivity: typing_extensions.TypeAlias = KnowledgeActivity

@typing.final
class KnowledgeMetadata(google.protobuf.message.Message):
    """use to track number of nodes created"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    TYPENAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    type: builtins.str
    """the type e.g. 'Node' or 'Relationship'"""
    typeName: builtins.str
    """the name of the type e.g. 'Service', 'defined_in'"""
    value: builtins.int
    """the number of these type created"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        typeName: builtins.str = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type", b"type", "typeName", b"typeName", "value", b"value"]) -> None: ...

Global___KnowledgeMetadata: typing_extensions.TypeAlias = KnowledgeMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import insightproto.proto.common.v1.common_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class JobStartEvent(google.protobuf.message.Message):
    """send when a job starts"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the job"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "org", b"org"]) -> None: ...

Global___JobStartEvent: typing_extensions.TypeAlias = JobStartEvent

@typing.final
class JobStopEvent(google.protobuf.message.Message):
    """send when a job as stopped"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the job"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    @property
    def error(self) -> Global___Error:
        """the error from the job"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        error: Global___Error | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_error", b"_error", "error", b"error", "org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_error", b"_error", "error", b"error", "id", b"id", "org", b"org"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_error", b"_error"]) -> typing.Literal["error"] | None: ...

Global___JobStopEvent: typing_extensions.TypeAlias = JobStopEvent

@typing.final
class Error(google.protobuf.message.Message):
    """An Error from the job running"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERRTYPE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TRACE_FIELD_NUMBER: builtins.int
    errType: builtins.str
    """the error type e.g. NullPointerException"""
    message: builtins.str
    """the error message"""
    trace: builtins.str
    """the trace as a string"""
    def __init__(
        self,
        *,
        errType: builtins.str = ...,
        message: builtins.str = ...,
        trace: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["errType", b"errType", "message", b"message", "trace", b"trace"]) -> None: ...

Global___Error: typing_extensions.TypeAlias = Error



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import insightproto.proto.common.v1.common_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AgentEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    AGENTID_FIELD_NUMBER: builtins.int
    THOUGHT_FIELD_NUMBER: builtins.int
    TOOL_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """The investigation ID that this update relates to."""
    agentId: builtins.str
    """the agent id"""
    thought: builtins.str
    """a thought the agent has had"""
    tool: builtins.str
    """a tool the agent has called"""
    error: builtins.str
    """a recoverable error in the flow"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp of the event"""

    def __init__(
        self,
        *,
        investigation_id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        agentId: builtins.str = ...,
        thought: builtins.str | None = ...,
        tool: builtins.str | None = ...,
        error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_error", b"_error", "_thought", b"_thought", "_tool", b"_tool", "error", b"error", "org", b"org", "thought", b"thought", "timestamp", b"timestamp", "tool", b"tool"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_error", b"_error", "_thought", b"_thought", "_tool", b"_tool", "agentId", b"agentId", "error", b"error", "investigation_id", b"investigation_id", "org", b"org", "thought", b"thought", "timestamp", b"timestamp", "tool", b"tool"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_error", b"_error"]) -> typing.Literal["error"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_thought", b"_thought"]) -> typing.Literal["thought"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_tool", b"_tool"]) -> typing.Literal["tool"] | None: ...

Global___AgentEvent: typing_extensions.TypeAlias = AgentEvent

@typing.final
class AgentStartedEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    PARENTAGENTID_FIELD_NUMBER: builtins.int
    AGENTID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    GOAL_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """The investigation ID that this update relates to."""
    parentAgentId: builtins.str
    """the id of the agent that started this agent"""
    agentId: builtins.str
    """the agent id"""
    name: builtins.str
    """the agent display name"""
    goal: builtins.str
    """the goal of the agent"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp of the event"""

    def __init__(
        self,
        *,
        investigation_id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        parentAgentId: builtins.str = ...,
        agentId: builtins.str = ...,
        name: builtins.str = ...,
        goal: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["org", b"org", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agentId", b"agentId", "goal", b"goal", "investigation_id", b"investigation_id", "name", b"name", "org", b"org", "parentAgentId", b"parentAgentId", "timestamp", b"timestamp"]) -> None: ...

Global___AgentStartedEvent: typing_extensions.TypeAlias = AgentStartedEvent

@typing.final
class AgentStoppedEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    AGENTID_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """The investigation ID that this update relates to."""
    agentId: builtins.str
    """the agent id"""
    error: builtins.str
    """an error that prevented normal agent flow"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp of the event"""

    def __init__(
        self,
        *,
        investigation_id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        agentId: builtins.str = ...,
        error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_error", b"_error", "error", b"error", "org", b"org", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_error", b"_error", "agentId", b"agentId", "error", b"error", "investigation_id", b"investigation_id", "org", b"org", "timestamp", b"timestamp"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_error", b"_error"]) -> typing.Literal["error"] | None: ...

Global___AgentStoppedEvent: typing_extensions.TypeAlias = AgentStoppedEvent



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from insightproto.proto.results.v1 import results_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_results__pb2
from insightproto.proto.results.v1 import updates_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2

GRPC_GENERATED_VERSION = '1.71.2'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in insightproto/proto/results/v1/updates_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UpdateServiceStub(object):
    """UpdateService provides a gRPC service for streaming real-time updates
    during investigation processing.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamUpdates = channel.stream_unary(
                '/insightproto.proto.results.v1.UpdateService/StreamUpdates',
                request_serializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.UpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.Thinking = channel.unary_unary(
                '/insightproto.proto.results.v1.UpdateService/Thinking',
                request_serializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Thought.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.Phase1UpdateResult = channel.unary_unary(
                '/insightproto.proto.results.v1.UpdateService/Phase1UpdateResult',
                request_serializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Phase1Update.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.Phase2UpdateResult = channel.unary_unary(
                '/insightproto.proto.results.v1.UpdateService/Phase2UpdateResult',
                request_serializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Phase2Update.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.Phase3UpdateResult = channel.unary_unary(
                '/insightproto.proto.results.v1.UpdateService/Phase3UpdateResult',
                request_serializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Phase3Update.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CompleteInvestigation = channel.unary_unary(
                '/insightproto.proto.results.v1.UpdateService/CompleteInvestigation',
                request_serializer=insightproto_dot_proto_dot_results_dot_v1_dot_results__pb2.InvestigationResult.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)


class UpdateServiceServicer(object):
    """UpdateService provides a gRPC service for streaming real-time updates
    during investigation processing.
    """

    def StreamUpdates(self, request_iterator, context):
        """StreamUpdates allows server-side streaming of updates from the agent
        to the server. The agent sends incremental updates without requiring acknowledgement.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Thinking(self, request, context):
        """Thinking allows the agent to communicate a new thought
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Phase1UpdateResult(self, request, context):
        """allow the agent to send the result of the phase1 update as soon as it is ready
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Phase2UpdateResult(self, request, context):
        """post the phase 2 results
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Phase3UpdateResult(self, request, context):
        """post the phase 3 results
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompleteInvestigation(self, request, context):
        """Post the complete investigation result
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UpdateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamUpdates': grpc.stream_unary_rpc_method_handler(
                    servicer.StreamUpdates,
                    request_deserializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.UpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Thinking': grpc.unary_unary_rpc_method_handler(
                    servicer.Thinking,
                    request_deserializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Thought.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Phase1UpdateResult': grpc.unary_unary_rpc_method_handler(
                    servicer.Phase1UpdateResult,
                    request_deserializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Phase1Update.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Phase2UpdateResult': grpc.unary_unary_rpc_method_handler(
                    servicer.Phase2UpdateResult,
                    request_deserializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Phase2Update.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Phase3UpdateResult': grpc.unary_unary_rpc_method_handler(
                    servicer.Phase3UpdateResult,
                    request_deserializer=insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Phase3Update.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CompleteInvestigation': grpc.unary_unary_rpc_method_handler(
                    servicer.CompleteInvestigation,
                    request_deserializer=insightproto_dot_proto_dot_results_dot_v1_dot_results__pb2.InvestigationResult.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'insightproto.proto.results.v1.UpdateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('insightproto.proto.results.v1.UpdateService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UpdateService(object):
    """UpdateService provides a gRPC service for streaming real-time updates
    during investigation processing.
    """

    @staticmethod
    def StreamUpdates(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/insightproto.proto.results.v1.UpdateService/StreamUpdates',
            insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.UpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Thinking(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/insightproto.proto.results.v1.UpdateService/Thinking',
            insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Thought.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Phase1UpdateResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/insightproto.proto.results.v1.UpdateService/Phase1UpdateResult',
            insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Phase1Update.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Phase2UpdateResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/insightproto.proto.results.v1.UpdateService/Phase2UpdateResult',
            insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Phase2Update.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Phase3UpdateResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/insightproto.proto.results.v1.UpdateService/Phase3UpdateResult',
            insightproto_dot_proto_dot_results_dot_v1_dot_updates__pb2.Phase3Update.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CompleteInvestigation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/insightproto.proto.results.v1.UpdateService/CompleteInvestigation',
            insightproto_dot_proto_dot_results_dot_v1_dot_results__pb2.InvestigationResult.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/flow.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/flow.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(insightproto/proto/results/v1/flow.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\"\xe2\x02\n\nAgentEvent\x12\x18\n\x10investigation_id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61gentId\x18\x04 \x01(\t\x12\x38\n\x07thought\x18\x05 \x01(\tB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"thought,omitempty\"H\x00\x88\x01\x01\x12\x32\n\x04tool\x18\x06 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"tool,omitempty\"H\x01\x88\x01\x01\x12\x34\n\x05\x65rror\x18\x07 \x01(\tB \x9a\x84\x9e\x03\x1b\x66irestore:\"error,omitempty\"H\x02\x88\x01\x01\x42\n\n\x08_thoughtB\x07\n\x05_toolB\x08\n\x06_error\"\xd9\x01\n\x11\x41gentStartedEvent\x12\x18\n\x10investigation_id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rparentAgentId\x18\x04 \x01(\t\x12\x0f\n\x07\x61gentId\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04goal\x18\x07 \x01(\t\"\xe6\x01\n\x11\x41gentStoppedEvent\x12\x18\n\x10investigation_id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61gentId\x18\x04 \x01(\t\x12\x34\n\x05\x65rror\x18\x05 \x01(\tB \x9a\x84\x9e\x03\x1b\x66irestore:\"error,omitempty\"H\x00\x88\x01\x01\x42\x08\n\x06_error2\x94\x02\n\tAgentFlow\x12X\n\x0c\x41gentStarted\x12\x30.insightproto.proto.results.v1.AgentStartedEvent\x1a\x16.google.protobuf.Empty\x12S\n\x0eSendAgentEvent\x12).insightproto.proto.results.v1.AgentEvent\x1a\x16.google.protobuf.Empty\x12X\n\x0c\x41gentStopped\x12\x30.insightproto.proto.results.v1.AgentStoppedEvent\x1a\x16.google.protobuf.EmptyB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.flow_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_AGENTEVENT'].fields_by_name['thought']._loaded_options = None
  _globals['_AGENTEVENT'].fields_by_name['thought']._serialized_options = b'\232\204\236\003\035firestore:\"thought,omitempty\"'
  _globals['_AGENTEVENT'].fields_by_name['tool']._loaded_options = None
  _globals['_AGENTEVENT'].fields_by_name['tool']._serialized_options = b'\232\204\236\003\032firestore:\"tool,omitempty\"'
  _globals['_AGENTEVENT'].fields_by_name['error']._loaded_options = None
  _globals['_AGENTEVENT'].fields_by_name['error']._serialized_options = b'\232\204\236\003\033firestore:\"error,omitempty\"'
  _globals['_AGENTSTOPPEDEVENT'].fields_by_name['error']._loaded_options = None
  _globals['_AGENTSTOPPEDEVENT'].fields_by_name['error']._serialized_options = b'\232\204\236\003\033firestore:\"error,omitempty\"'
  _globals['_AGENTEVENT']._serialized_start=181
  _globals['_AGENTEVENT']._serialized_end=535
  _globals['_AGENTSTARTEDEVENT']._serialized_start=538
  _globals['_AGENTSTARTEDEVENT']._serialized_end=755
  _globals['_AGENTSTOPPEDEVENT']._serialized_start=758
  _globals['_AGENTSTOPPEDEVENT']._serialized_end=988
  _globals['_AGENTFLOW']._serialized_start=991
  _globals['_AGENTFLOW']._serialized_end=1267
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/jobs/v1/job_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/jobs/v1/job_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,insightproto/proto/jobs/v1/job_service.proto\x12\x1ainsightproto.proto.jobs.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a)insightproto/proto/common/v1/common.proto\"T\n\rJobStartEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\"\x94\x01\n\x0cJobStopEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x35\n\x05\x65rror\x18\x03 \x01(\x0b\x32!.insightproto.proto.jobs.v1.ErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"8\n\x05\x45rror\x12\x0f\n\x07\x65rrType\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05trace\x18\x03 \x01(\t2\xa8\x01\n\nJobService\x12M\n\x08JobStart\x12).insightproto.proto.jobs.v1.JobStartEvent\x1a\x16.google.protobuf.Empty\x12K\n\x07JobStop\x12(.insightproto.proto.jobs.v1.JobStopEvent\x1a\x16.google.protobuf.EmptyB/Z-github.com/opentrace/insight-proto-go/jobs/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.jobs.v1.job_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/opentrace/insight-proto-go/jobs/v1'
  _globals['_JOBSTARTEVENT']._serialized_start=148
  _globals['_JOBSTARTEVENT']._serialized_end=232
  _globals['_JOBSTOPEVENT']._serialized_start=235
  _globals['_JOBSTOPEVENT']._serialized_end=383
  _globals['_ERROR']._serialized_start=385
  _globals['_ERROR']._serialized_end=441
  _globals['_JOBSERVICE']._serialized_start=444
  _globals['_JOBSERVICE']._serialized_end=612
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import insightproto.proto.jobs.v1.jobs_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LogEntry(google.protobuf.message.Message):
    """LogEntry represents a single log entry with timestamp and message"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TS_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    msg: builtins.str
    """the log line message"""
    level: builtins.str
    """the log level (e.g. info, debug, error)"""
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp of the log line"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """the labels for the log line"""

    def __init__(
        self,
        *,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        msg: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        level: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["labels", b"labels", "level", b"level", "msg", b"msg", "ts", b"ts"]) -> None: ...

Global___LogEntry: typing_extensions.TypeAlias = LogEntry

@typing.final
class LogDetail(google.protobuf.message.Message):
    """LogDetail contains details for a logs-type timeline event"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGS_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    query: builtins.str
    """the query used to capture the logs e.g. the logql"""
    text: builtins.str
    """a text summary of the captured logs"""
    link: builtins.str
    """the link to view the logs in the source"""
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___LogEntry]:
        """the captured logs"""

    def __init__(
        self,
        *,
        logs: collections.abc.Iterable[Global___LogEntry] | None = ...,
        query: builtins.str = ...,
        text: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["link", b"link", "logs", b"logs", "query", b"query", "text", b"text"]) -> None: ...

Global___LogDetail: typing_extensions.TypeAlias = LogDetail

@typing.final
class Annotations(google.protobuf.message.Message):
    """Annotations represents chart annotations"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    Y_AXIS_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """unique identifier for the annotation"""
    type: builtins.str
    """type of annotation: 'line', 'area', 'point'"""
    label: builtins.str
    """display label for the annotation"""
    color: builtins.str
    """color for the annotation (hex, rgb, or CSS variable)"""
    value: builtins.float
    """value for horizontal line annotations"""
    y_axis_id: builtins.str
    """y-axis identifier for dual-axis charts"""
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """start timestamp for the annotation (required for line/point, optional for area)"""

    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """end timestamp for area annotations"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: builtins.str = ...,
        start_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        label: builtins.str = ...,
        color: builtins.str = ...,
        value: builtins.float | None = ...,
        y_axis_id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_end_timestamp", b"_end_timestamp", "_start_timestamp", b"_start_timestamp", "_value", b"_value", "_y_axis_id", b"_y_axis_id", "end_timestamp", b"end_timestamp", "start_timestamp", b"start_timestamp", "value", b"value", "y_axis_id", b"y_axis_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_end_timestamp", b"_end_timestamp", "_start_timestamp", b"_start_timestamp", "_value", b"_value", "_y_axis_id", b"_y_axis_id", "color", b"color", "end_timestamp", b"end_timestamp", "id", b"id", "label", b"label", "start_timestamp", b"start_timestamp", "type", b"type", "value", b"value", "y_axis_id", b"y_axis_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_end_timestamp", b"_end_timestamp"]) -> typing.Literal["end_timestamp"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_start_timestamp", b"_start_timestamp"]) -> typing.Literal["start_timestamp"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_value", b"_value"]) -> typing.Literal["value"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_y_axis_id", b"_y_axis_id"]) -> typing.Literal["y_axis_id"] | None: ...

Global___Annotations: typing_extensions.TypeAlias = Annotations

@typing.final
class Series(google.protobuf.message.Message):
    """Series represents a data series in a chart"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DATA_KEY_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    Y_AXIS_ID_FIELD_NUMBER: builtins.int
    STROKE_WIDTH_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    data_key: builtins.str
    """key to identify the data field in MetricData"""
    label: builtins.str
    """display label for the series"""
    type: builtins.str
    """chart type: 'line', 'bar', 'area', 'scatter'"""
    y_axis_id: builtins.str
    """y-axis identifier for dual-axis charts ('left' or 'right')"""
    stroke_width: builtins.int
    """line thickness in pixels"""
    color: builtins.str
    """color for the series (hex, rgb, or CSS variable)"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """labels attached to the metric as key-value pairs"""

    def __init__(
        self,
        *,
        data_key: builtins.str = ...,
        label: builtins.str = ...,
        type: builtins.str = ...,
        y_axis_id: builtins.str = ...,
        stroke_width: builtins.int = ...,
        color: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["color", b"color", "data_key", b"data_key", "label", b"label", "labels", b"labels", "stroke_width", b"stroke_width", "type", b"type", "y_axis_id", b"y_axis_id"]) -> None: ...

Global___Series: typing_extensions.TypeAlias = Series

@typing.final
class MetricData(google.protobuf.message.Message):
    """MetricData represents metric data points"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ValuesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TS_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timestamp for the data point"""

    @property
    def values(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """key-value pairs of series ids to their string values"""

    def __init__(
        self,
        *,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        values: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ts", b"ts", "values", b"values"]) -> None: ...

Global___MetricData: typing_extensions.TypeAlias = MetricData

@typing.final
class Layout(google.protobuf.message.Message):
    """Layout represents chart layout configuration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEFT_X_AXIS_LABEL_FIELD_NUMBER: builtins.int
    RIGHT_Y_AXIS_LABEL_FIELD_NUMBER: builtins.int
    left_x_axis_label: builtins.str
    """label for the left/primary y-axis"""
    right_y_axis_label: builtins.str
    """label for the right/secondary y-axis"""
    def __init__(
        self,
        *,
        left_x_axis_label: builtins.str = ...,
        right_y_axis_label: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["left_x_axis_label", b"left_x_axis_label", "right_y_axis_label", b"right_y_axis_label"]) -> None: ...

Global___Layout: typing_extensions.TypeAlias = Layout

@typing.final
class MetricDetail(google.protobuf.message.Message):
    """MetricDetail represents the collection ot metric values"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    SERIES_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    LAYOUT_FIELD_NUMBER: builtins.int
    query: builtins.str
    """the query used to capture the metrics"""
    text: builtins.str
    """a text summary of the captured metrics"""
    link: builtins.str
    """the link to view the metrics in the source"""
    title: builtins.str
    """the title of the graph"""
    @property
    def annotations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Annotations]:
        """the list of annotations to attach to the graph"""

    @property
    def series(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Series]:
        """the series to render"""

    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___MetricData]:
        """the metric data"""

    @property
    def layout(self) -> Global___Layout:
        """the layout customisations"""

    def __init__(
        self,
        *,
        query: builtins.str = ...,
        text: builtins.str = ...,
        link: builtins.str = ...,
        title: builtins.str = ...,
        annotations: collections.abc.Iterable[Global___Annotations] | None = ...,
        series: collections.abc.Iterable[Global___Series] | None = ...,
        data: collections.abc.Iterable[Global___MetricData] | None = ...,
        layout: Global___Layout | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_layout", b"_layout", "layout", b"layout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_layout", b"_layout", "annotations", b"annotations", "data", b"data", "layout", b"layout", "link", b"link", "query", b"query", "series", b"series", "text", b"text", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_layout", b"_layout"]) -> typing.Literal["layout"] | None: ...

Global___MetricDetail: typing_extensions.TypeAlias = MetricDetail

@typing.final
class User(google.protobuf.message.Message):
    """User contains information about a user (author, committer, approver, etc.)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """display name of the user"""
    user: builtins.str
    """username or handle"""
    image: builtins.str
    """URL to user's profile image/avatar"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        user: builtins.str = ...,
        image: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image", b"image", "name", b"name", "user", b"user"]) -> None: ...

Global___User: typing_extensions.TypeAlias = User

@typing.final
class CodeDetail(google.protobuf.message.Message):
    """CodeDetail contains details for a code-type timeline event"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_NAME_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    FILE_TYPE_FIELD_NUMBER: builtins.int
    LINE_START_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    HIGHLIGHTED_LINES_FIELD_NUMBER: builtins.int
    file_name: builtins.str
    """name of the file"""
    file_path: builtins.str
    """full path to the file"""
    file_type: builtins.str
    """file extension or type"""
    line_start: builtins.int
    """starting line number for the code snippet"""
    code: builtins.str
    """the actual code content"""
    commit: builtins.str
    """commit hash or identifier"""
    text: builtins.str
    """descriptive text about the code change"""
    link: builtins.str
    """link to view the code in the source system"""
    @property
    def author(self) -> Global___User:
        """author of the code change"""

    @property
    def highlighted_lines(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """line numbers to highlight in the code snippet"""

    def __init__(
        self,
        *,
        file_name: builtins.str = ...,
        file_path: builtins.str = ...,
        file_type: builtins.str = ...,
        line_start: builtins.int = ...,
        code: builtins.str = ...,
        commit: builtins.str = ...,
        author: Global___User | None = ...,
        text: builtins.str = ...,
        link: builtins.str = ...,
        highlighted_lines: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "code", b"code", "commit", b"commit", "file_name", b"file_name", "file_path", b"file_path", "file_type", b"file_type", "highlighted_lines", b"highlighted_lines", "line_start", b"line_start", "link", b"link", "text", b"text"]) -> None: ...

Global___CodeDetail: typing_extensions.TypeAlias = CodeDetail

@typing.final
class MergeRequestDetail(google.protobuf.message.Message):
    """MergeRequestDetail contains details for a merge-request-type timeline event"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHOR_FIELD_NUMBER: builtins.int
    APPROVERS_FIELD_NUMBER: builtins.int
    OPENED_FIELD_NUMBER: builtins.int
    MERGED_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    status: builtins.str
    """current status: 'open', 'merged', 'closed'"""
    text: builtins.str
    """descriptive text about the merge request"""
    link: builtins.str
    """link to view the merge request"""
    @property
    def author(self) -> Global___User:
        """author of the merge request"""

    @property
    def approvers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___User]:
        """users who approved the merge request"""

    @property
    def opened(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timestamp when the merge request was opened"""

    @property
    def merged(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timestamp when the merge request was merged"""

    def __init__(
        self,
        *,
        author: Global___User | None = ...,
        approvers: collections.abc.Iterable[Global___User] | None = ...,
        opened: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        merged: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: builtins.str = ...,
        text: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "merged", b"merged", "opened", b"opened"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["approvers", b"approvers", "author", b"author", "link", b"link", "merged", b"merged", "opened", b"opened", "status", b"status", "text", b"text"]) -> None: ...

Global___MergeRequestDetail: typing_extensions.TypeAlias = MergeRequestDetail

@typing.final
class CIDetail(google.protobuf.message.Message):
    """CIDetail contains details for a CI-type timeline event"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    pipeline_id: builtins.str
    """identifier for the CI pipeline"""
    job_id: builtins.str
    """identifier for the specific job within the pipeline"""
    log: builtins.str
    """log output from the CI job"""
    text: builtins.str
    """descriptive text about the CI event"""
    link: builtins.str
    """link to view the CI job details"""
    def __init__(
        self,
        *,
        pipeline_id: builtins.str = ...,
        job_id: builtins.str = ...,
        log: builtins.str = ...,
        text: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id", "link", b"link", "log", b"log", "pipeline_id", b"pipeline_id", "text", b"text"]) -> None: ...

Global___CIDetail: typing_extensions.TypeAlias = CIDetail

@typing.final
class KnowledgeDetail(google.protobuf.message.Message):
    """KnowledgeDetail contains details for a knowledge-type timeline event"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    text: builtins.str
    """descriptive text about the knowledge item"""
    link: builtins.str
    """link to the knowledge resource"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["link", b"link", "text", b"text"]) -> None: ...

Global___KnowledgeDetail: typing_extensions.TypeAlias = KnowledgeDetail

@typing.final
class TicketDetail(google.protobuf.message.Message):
    """TicketDetail contains details for a ticket-type timeline event"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    TICKET_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """identifier for the project containing the ticket"""
    ticket_id: builtins.str
    """unique identifier for the ticket"""
    text: builtins.str
    """descriptive text about the ticket"""
    link: builtins.str
    """link to view the ticket"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """tags or labels associated with the ticket"""

    @property
    def author(self) -> Global___User:
        """author or creator of the ticket"""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        ticket_id: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        author: Global___User | None = ...,
        text: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "link", b"link", "project_id", b"project_id", "tags", b"tags", "text", b"text", "ticket_id", b"ticket_id"]) -> None: ...

Global___TicketDetail: typing_extensions.TypeAlias = TicketDetail

@typing.final
class TriggerDetail(google.protobuf.message.Message):
    """TriggerDetail contains information about the source of a trigger event"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    trigger_source: builtins.str
    """deprecated see trigger"""
    text: builtins.str
    """descriptive text about the trigger event"""
    link: builtins.str
    """link to view the trigger source"""
    @property
    def trigger(self) -> insightproto.proto.jobs.v1.jobs_pb2.Trigger:
        """the trigger info for the investigation"""

    def __init__(
        self,
        *,
        trigger_source: builtins.str = ...,
        trigger: insightproto.proto.jobs.v1.jobs_pb2.Trigger | None = ...,
        text: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["link", b"link", "text", b"text", "trigger", b"trigger", "trigger_source", b"trigger_source"]) -> None: ...

Global___TriggerDetail: typing_extensions.TypeAlias = TriggerDetail

@typing.final
class GenericDetail(google.protobuf.message.Message):
    """GenericDetail contains details for a generic data-type timeline event"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    text: builtins.str
    """descriptive text about the generic event"""
    link: builtins.str
    """link to view more details about the event"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["link", b"link", "text", b"text"]) -> None: ...

Global___GenericDetail: typing_extensions.TypeAlias = GenericDetail



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/jobs/v2/job_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/jobs/v2/job_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,insightproto/proto/jobs/v2/job_service.proto\x12\x1ainsightproto.proto.jobs.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a)insightproto/proto/common/v1/common.proto\"R\n\rJobIdentifier\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.insightproto.proto.jobs.v2.JobType\"\xbb\x05\n\x08JobEvent\x12\x37\n\x03org\x18\x01 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x36\n\x03job\x18\x02 \x01(\x0b\x32).insightproto.proto.jobs.v2.JobIdentifier\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x05\x61gent\x18\x04 \x01(\x0b\x32!.insightproto.proto.jobs.v2.Agent\x12;\n\x07thought\x18\n \x01(\x0b\x32(.insightproto.proto.jobs.v2.ThoughtEventH\x00\x12>\n\ttool_call\x18\x0b \x01(\x0b\x32).insightproto.proto.jobs.v2.ToolCallEventH\x00\x12\x42\n\x0btool_result\x18\x0c \x01(\x0b\x32+.insightproto.proto.jobs.v2.ToolResultEventH\x00\x12\x46\n\ragent_started\x18\r \x01(\x0b\x32-.insightproto.proto.jobs.v2.AgentStartedEventH\x00\x12\x46\n\ragent_stopped\x18\x0e \x01(\x0b\x32-.insightproto.proto.jobs.v2.AgentStoppedEventH\x00\x12=\n\x08progress\x18\x0f \x01(\x0b\x32).insightproto.proto.jobs.v2.ProgressEventH\x00\x12\x44\n\x0c\x63hat_content\x18\x10 \x01(\x0b\x32,.insightproto.proto.jobs.v2.ChatContentEventH\x00\x42\x07\n\x05\x65vent\"\x15\n\x05\x41gent\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1f\n\x0cThoughtEvent\x12\x0f\n\x07thought\x18\x01 \x01(\t\"\x8c\x01\n\rToolCallEvent\x12\x14\n\x0ctool_call_id\x18\x01 \x01(\t\x12\x11\n\ttool_name\x18\x02 \x01(\t\x12\x17\n\nmcp_server\x18\x03 \x01(\tH\x00\x88\x01\x01\x12*\n\targuments\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB\r\n\x0b_mcp_server\"\xb4\x01\n\x0fToolResultEvent\x12\x14\n\x0ctool_call_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12,\n\x06result\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x0b\x64uration_ms\x18\x05 \x01(\x03\x42\t\n\x07_resultB\x10\n\x0e_error_message\"/\n\x11\x41gentStartedEvent\x12\x11\n\x04goal\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_goal\"1\n\x11\x41gentStoppedEvent\x12\x12\n\x05\x65rror\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_error\"B\n\rProgressEvent\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x14\n\x07percent\x18\x02 \x01(\x05H\x00\x88\x01\x01\x42\n\n\x08_percent\"\x84\x01\n\x10\x43hatContentEvent\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\x08sequence\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x08\x63omplete\x18\x03 \x01(\x08\x12\x17\n\x0f\x63onversation_id\x18\x04 \x01(\t\x12\x13\n\x0bresponse_id\x18\x05 \x01(\tB\x0b\n\t_sequence*\x91\x01\n\x07JobType\x12\x18\n\x14JOB_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10JOB_TYPE_INSIGHT\x10\x01\x12\x13\n\x0fJOB_TYPE_AETHER\x10\x02\x12\x16\n\x12JOB_TYPE_SIMULATOR\x10\x03\x12\x16\n\x12JOB_TYPE_KNOWLEDGE\x10\x04\x12\x11\n\rJOB_TYPE_CHAT\x10\x05\x32W\n\nJobService\x12I\n\tPostEvent\x12$.insightproto.proto.jobs.v2.JobEvent\x1a\x16.google.protobuf.EmptyB/Z-github.com/opentrace/insight-proto-go/jobs/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.jobs.v2.job_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/opentrace/insight-proto-go/jobs/v2'
  _globals['_JOBTYPE']._serialized_start=1683
  _globals['_JOBTYPE']._serialized_end=1828
  _globals['_JOBIDENTIFIER']._serialized_start=211
  _globals['_JOBIDENTIFIER']._serialized_end=293
  _globals['_JOBEVENT']._serialized_start=296
  _globals['_JOBEVENT']._serialized_end=995
  _globals['_AGENT']._serialized_start=997
  _globals['_AGENT']._serialized_end=1018
  _globals['_THOUGHTEVENT']._serialized_start=1020
  _globals['_THOUGHTEVENT']._serialized_end=1051
  _globals['_TOOLCALLEVENT']._serialized_start=1054
  _globals['_TOOLCALLEVENT']._serialized_end=1194
  _globals['_TOOLRESULTEVENT']._serialized_start=1197
  _globals['_TOOLRESULTEVENT']._serialized_end=1377
  _globals['_AGENTSTARTEDEVENT']._serialized_start=1379
  _globals['_AGENTSTARTEDEVENT']._serialized_end=1426
  _globals['_AGENTSTOPPEDEVENT']._serialized_start=1428
  _globals['_AGENTSTOPPEDEVENT']._serialized_end=1477
  _globals['_PROGRESSEVENT']._serialized_start=1479
  _globals['_PROGRESSEVENT']._serialized_end=1545
  _globals['_CHATCONTENTEVENT']._serialized_start=1548
  _globals['_CHATCONTENTEVENT']._serialized_end=1680
  _globals['_JOBSERVICE']._serialized_start=1830
  _globals['_JOBSERVICE']._serialized_end=1917
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import insightproto.proto.common.v1.common_pb2
import insightproto.proto.jobs.v1.jobs_pb2
import insightproto.proto.results.v1.results_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InsightComplete(google.protobuf.message.Message):
    """this is used to publish an event to indicate that the insight job is complete"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    CLOSEDAT_FIELD_NUMBER: builtins.int
    CREATEDAT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    HYPOTHESES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the job"""
    title: builtins.str
    """the investigation title"""
    summary: builtins.str
    """the investigation summary"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """the organisation the job is for"""

    @property
    def trigger(self) -> insightproto.proto.jobs.v1.jobs_pb2.Trigger:
        """the triggering event"""

    @property
    def closedAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time this was closed"""

    @property
    def createdAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time this investigation was created"""

    @property
    def hypotheses(self) -> insightproto.proto.results.v1.results_pb2.Hypothesis:
        """the investigation key hypothesis"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        trigger: insightproto.proto.jobs.v1.jobs_pb2.Trigger | None = ...,
        closedAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        createdAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        title: builtins.str = ...,
        summary: builtins.str = ...,
        hypotheses: insightproto.proto.results.v1.results_pb2.Hypothesis | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["closedAt", b"closedAt", "createdAt", b"createdAt", "hypotheses", b"hypotheses", "org", b"org", "trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["closedAt", b"closedAt", "createdAt", b"createdAt", "hypotheses", b"hypotheses", "id", b"id", "org", b"org", "summary", b"summary", "title", b"title", "trigger", b"trigger"]) -> None: ...

Global___InsightComplete: typing_extensions.TypeAlias = InsightComplete



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/simulator.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/simulator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.jobs.v1 import jobs_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_jobs__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-insightproto/proto/results/v1/simulator.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a%insightproto/proto/jobs/v1/jobs.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xd8\x02\n\x17SimulatorResultsRequest\x12\x37\n\x03org\x18\x01 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12?\n\rsimulator_job\x18\x02 \x01(\x0b\x32(.insightproto.proto.jobs.v1.SimulatorJob\x12\x15\n\ragent_job_ids\x18\x03 \x03(\t\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\x11\x65valuation_result\x18\x06 \x01(\x0b\x32/.insightproto.proto.results.v1.EvaluationResult\"\xab\x02\n\x10\x45valuationResult\x12\x0f\n\x07summary\x18\x01 \x01(\t\x12\x15\n\roverall_score\x18\x02 \x01(\x05\x12\x18\n\x10\x61nalysis_quality\x18\x03 \x01(\t\x12\x1b\n\x13\x61\x63\x63uracy_assessment\x18\x04 \x01(\t\x12R\n\x15\x61reas_for_improvement\x18\x05 \x01(\tB.\x9a\x84\x9e\x03)firestore:\"areasForImprovement,omitempty\"H\x00\x88\x01\x01\x12<\n\tstrengths\x18\x06 \x01(\tB$\x9a\x84\x9e\x03\x1f\x66irestore:\"strengths,omitempty\"H\x01\x88\x01\x01\x42\x18\n\x16_areas_for_improvementB\x0c\n\n_strengths2z\n\x17SimulatorResultsService\x12_\n\rSubmitResults\x12\x36.insightproto.proto.results.v1.SimulatorResultsRequest\x1a\x16.google.protobuf.EmptyB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.simulator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_EVALUATIONRESULT'].fields_by_name['areas_for_improvement']._loaded_options = None
  _globals['_EVALUATIONRESULT'].fields_by_name['areas_for_improvement']._serialized_options = b'\232\204\236\003)firestore:\"areasForImprovement,omitempty\"'
  _globals['_EVALUATIONRESULT'].fields_by_name['strengths']._loaded_options = None
  _globals['_EVALUATIONRESULT'].fields_by_name['strengths']._serialized_options = b'\232\204\236\003\037firestore:\"strengths,omitempty\"'
  _globals['_SIMULATORRESULTSREQUEST']._serialized_start=225
  _globals['_SIMULATORRESULTSREQUEST']._serialized_end=569
  _globals['_EVALUATIONRESULT']._serialized_start=572
  _globals['_EVALUATIONRESULT']._serialized_end=871
  _globals['_SIMULATORRESULTSSERVICE']._serialized_start=873
  _globals['_SIMULATORRESULTSSERVICE']._serialized_end=995
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import insightproto.proto.common.v1.common_pb2
import insightproto.proto.results.v1.results_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Phase1Update(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    ALERT_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """The investigation ID that this update relates to."""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    @property
    def alert(self) -> insightproto.proto.results.v1.results_pb2.AlertExtraction:
        """The alert data that was extracted"""

    def __init__(
        self,
        *,
        investigation_id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        alert: insightproto.proto.results.v1.results_pb2.AlertExtraction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["alert", b"alert", "org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["alert", b"alert", "investigation_id", b"investigation_id", "org", b"org"]) -> None: ...

Global___Phase1Update: typing_extensions.TypeAlias = Phase1Update

@typing.final
class Phase2Update(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    HYPOTHESES_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """The investigation ID that this update relates to."""
    priority: builtins.str
    """the investigation priority (low/medium/high/critical/pending)"""
    description: builtins.str
    """the description"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    @property
    def hypotheses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[insightproto.proto.results.v1.results_pb2.Hypothesis]:
        """the produced hypotheses"""

    def __init__(
        self,
        *,
        investigation_id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        hypotheses: collections.abc.Iterable[insightproto.proto.results.v1.results_pb2.Hypothesis] | None = ...,
        priority: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "hypotheses", b"hypotheses", "investigation_id", b"investigation_id", "org", b"org", "priority", b"priority"]) -> None: ...

Global___Phase2Update: typing_extensions.TypeAlias = Phase2Update

@typing.final
class Phase3Update(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """The investigation ID that this update relates to."""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    def __init__(
        self,
        *,
        investigation_id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["investigation_id", b"investigation_id", "org", b"org"]) -> None: ...

Global___Phase3Update: typing_extensions.TypeAlias = Phase3Update

@typing.final
class Thought(google.protobuf.message.Message):
    """a thought the agent has used to define it's next steps"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    HYPOTHESIS_ID_FIELD_NUMBER: builtins.int
    THOUGHT_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """The investigation ID that this update relates to."""
    hypothesis_id: builtins.str
    """hypothesis_id is the id of the active hypothesis"""
    thought: builtins.str
    """the new thought being made"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    def __init__(
        self,
        *,
        investigation_id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        hypothesis_id: builtins.str = ...,
        thought: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hypothesis_id", b"hypothesis_id", "investigation_id", b"investigation_id", "org", b"org", "thought", b"thought"]) -> None: ...

Global___Thought: typing_extensions.TypeAlias = Thought

@typing.final
class UpdateRequest(google.protobuf.message.Message):
    """UpdateRequest represents an incremental update sent by the agent during
    investigation processing.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """The investigation ID that this update relates to."""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    @property
    def event(self) -> insightproto.proto.results.v1.results_pb2.TimelineEvent:
        """The timeline event data for this update."""

    def __init__(
        self,
        *,
        investigation_id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        event: insightproto.proto.results.v1.results_pb2.TimelineEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["event", b"event", "org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["event", b"event", "investigation_id", b"investigation_id", "org", b"org"]) -> None: ...

Global___UpdateRequest: typing_extensions.TypeAlias = UpdateRequest
